@@ -15,9 +15,9 @@ import hashlib
 import imutils
 import numpy as np
 from os.path import exists, join
-from detector import HoopDetector, BallDetector
+from ww_audio_shot_detection.detector import HoopDetector, BallDetector
 from keras_retinanet.utils.image import preprocess_image, resize_image
-from utils import download_model, download_file_async, Rectangle, get_frame_by_index, show_images, resize_rect
+from ww_audio_shot_detection.utils import download_model, download_file_async, Rectangle, get_frame_by_index, show_images, resize_rect
 import librosa as lr
 from scipy.signal import find_peaks
 import subprocess
